==> haskell-esqueleto-3.3.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 3.3.0
id: esqueleto-3.3.0-7nIH5kSt4A92eCxLY6fPS1
key: esqueleto-3.3.0-7nIH5kSt4A92eCxLY6fPS1
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: a5ea06a9e5a89b90cd1132f2859a60b3
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal
    Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.PostgreSQL.JSON
    Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.PersistentImport
                Database.Esqueleto.PostgreSQL.JSON.Instances Paths_esqueleto
import-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/esqueleto-3.3.0
hs-libraries: HSesqueleto-3.3.0-7nIH5kSt4A92eCxLY6fPS1
depends:
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s
    attoparsec-0.13.2.3-7zk58GWWjTj9W2Qd2JktwB base-4.12.0.0
    blaze-html-0.9.1.2-3rCj4yYYlH244V10MP4Bb5 bytestring-0.10.8.2
    conduit-1.3.1.2-KNywdU6deAEKB3TItOoWtt containers-0.6.0.1
    monad-logger-0.3.31-6NsHkoUGsUU6puDnRXD7Jc
    persistent-2.10.4-FmLV1YMIfDTLIGh748uiF6
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-0.2.12-EZdNAvVHW1A5uRUDx4sbmX
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-esqueleto-3.3.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 3.3.0
id: esqueleto-3.3.0-6vDdODuMbljAs2dt78Lqts
key: esqueleto-3.3.0-6vDdODuMbljAs2dt78Lqts
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: 41efb3b9109fa1358f0484e7797ed852
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal
    Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.PostgreSQL.JSON
    Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.PersistentImport
                Database.Esqueleto.PostgreSQL.JSON.Instances Paths_esqueleto
import-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/esqueleto-3.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/esqueleto-3.3.0
hs-libraries: HSesqueleto-3.3.0-6vDdODuMbljAs2dt78Lqts
depends:
    aeson-1.4.6.0-ByJnT4jukmB1Ih4DIu8bQB
    attoparsec-0.13.2.3-8w0M5Ys1O3I8OHsDdXIpYC base-4.12.0.0
    blaze-html-0.9.1.2-46zU1Jl1PZV3zFjN4bwuoM bytestring-0.10.8.2
    conduit-1.3.1.2-FrtJMTY3M2CAC8GVZl6Z8t containers-0.6.0.1
    monad-logger-0.3.31-1KLw0xA9VBN3o0piHDrrdG
    persistent-2.10.4-7QeSPEA638ZJE8mBsL1Kco
    resourcet-1.2.2-B6MNSo3GKFWL8hVHO97lMf
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-0.2.12-A1Gsmj9ZKmI3R6gP4drz58
    unordered-containers-0.2.10.0-EKmGslSZSRGGEQm9fn2qPS
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
